@@ -1,5 +1,5 @@
 from .metasv import MetaSV
-from .provider import Provider
+from .provider import Provider, BroadcastResult
 from .sensiblequery import SensibleQuery
 from .service import Service
 from .whatsonchain import WhatsOnChain
